Module debug

Module debug 

Factomd debug functions.

Structs

App
AuditServers
Authorities
Authority
Configuration
configuration and reload-configuration functions
Delay
delay and set-delay functions
DropRate
drop-rate and set-drop-rate functions
FederatedServer
FederatedServers
HoldingQueue
holding-queue function
Log
Messages
NetworkInfo
Peer
PredictiveFER
ProcessList
Summary
Wallet
Walletd

Functions

audit_servers
Get a list of the current network audit servers along with their information.
authorities
List of authority servers in the management chain.
configuration
Get the current configuration state from factomd.conf.
delay
Get the current msg delay time for network testing.
drop_rate
Get the current package drop rate for network testing.
federated_servers
Get a list of the current network federated servers along with their information.
holding_queue
Show current holding messages in the queue.
messages
Get a list of messages from the message journal (must run factomd with -journaling=true)
network_info
Get information on the current network factomd is connected to (TEST, MAIN, etc)
predictive_fer
Get the predicted future entry credit rate. ///
process_list
Get the process list known to the current factomd instance.
reload_configuration
Causes factomd to re-read the configuration from the config file. Note: This may cause consensus problems and could be impractical even in testing.
set_delay
Set the current msg delay time for network testing.
set_drop_rate
Change the network drop rate for testing.
summary
Get the nodes summary string.