Factomd debug functions.
Structs
- App
- Audit
Servers - Authorities
- Authority
- Configuration
- configuration and reload-configuration functions
- Delay
- delay and set-delay functions
- Drop
Rate - drop-rate and set-drop-rate functions
- Federated
Server - Federated
Servers - Holding
Queue - holding-queue function
- Log
- Messages
- Network
Info - Peer
- PredictiveFER
- Process
List - Summary
- Wallet
- Walletd
Functions
- audit_
servers - Get a list of the current network audit servers along with their information.
- authorities
- List of authority servers in the management chain.
- configuration
- Get the current configuration state from factomd.conf.
- delay
- Get the current msg delay time for network testing.
- drop_
rate - Get the current package drop rate for network testing.
- federated_
servers - Get a list of the current network federated servers along with their information.
- holding_
queue - Show current holding messages in the queue.
- messages
- Get a list of messages from the message journal (must run factomd with -journaling=true)
- network_
info - Get information on the current network factomd is connected to (TEST, MAIN, etc)
- predictive_
fer - Get the predicted future entry credit rate. ///
- process_
list - Get the process list known to the current factomd instance.
- reload_
configuration - Causes factomd to re-read the configuration from the config file. Note: This may cause consensus problems and could be impractical even in testing.
- set_
delay - Set the current msg delay time for network testing.
- set_
drop_ rate - Change the network drop rate for testing.
- summary
- Get the nodes summary string.